@@ -31,6 +31,9 @@
 #include "empathy-connection-managers.h"
 #include "empathy-utils.h"
 
+#define DEBUG_FLAG EMPATHY_DEBUG_ACCOUNT
+#include <libempathy/empathy-debug.h>
+
 #define GET_PRIV(obj) EMPATHY_GET_PRIV (obj, EmpathyAccountSettings)
 
 G_DEFINE_TYPE(EmpathyAccountSettings, empathy_account_settings, G_TYPE_OBJECT)
@@ -55,7 +58,6 @@ struct _EmpathyAccountSettingsPriv
   gulong account_manager_ready_id;
 
   TpConnectionManager *manager;
-  const TpConnectionManagerProtocol *tp_protocol;
 
   EmpathyAccount *account;
   gchar *cm_name;
@@ -338,6 +340,9 @@ empathy_account_settings_finalize (GObject *object)
   g_free (priv->display_name);
   g_free (priv->icon_name);
 
+  if (priv->required_params != NULL)
+    g_array_free (priv->required_params, TRUE);
+
   g_hash_table_destroy (priv->parameters);
 
   empathy_account_settings_free_unset_parameters (self);
@@ -350,6 +355,7 @@ static void
 empathy_account_settings_check_readyness (EmpathyAccountSettings *self)
 {
   EmpathyAccountSettingsPriv *priv = GET_PRIV (self);
+  const TpConnectionManagerProtocol *tp_protocol;
 
   if (priv->ready)
     return;
@@ -377,10 +383,10 @@ empathy_account_settings_check_readyness (EmpathyAccountSettings *self)
         g_strdup (empathy_account_get_icon_name (priv->account));
     }
 
-  priv->tp_protocol = tp_connection_manager_get_protocol (priv->manager,
+  tp_protocol = tp_connection_manager_get_protocol (priv->manager,
     priv->protocol);
 
-  if (priv->tp_protocol == NULL)
+  if (tp_protocol == NULL)
     {
       priv->manager = NULL;
       return;
@@ -393,7 +399,7 @@ empathy_account_settings_check_readyness (EmpathyAccountSettings *self)
 
       priv->required_params = g_array_new (TRUE, FALSE, sizeof (gchar *));
 
-      for (cur = priv->tp_protocol->params; cur->name != NULL; cur++)
+      for (cur = tp_protocol->params; cur->name != NULL; cur++)
         {
           if (tp_connection_manager_param_is_required (cur))
             {
@@ -443,10 +449,21 @@ TpConnectionManagerParam *
 empathy_account_settings_get_tp_params (EmpathyAccountSettings *settings)
 {
   EmpathyAccountSettingsPriv *priv = GET_PRIV (settings);
+  const TpConnectionManagerProtocol *tp_protocol;
 
-  g_return_val_if_fail (priv->tp_protocol != NULL, NULL);
+  g_return_val_if_fail (priv->manager != NULL, NULL);
+  g_return_val_if_fail (priv->protocol != NULL, NULL);
 
-  return priv->tp_protocol->params;
+  tp_protocol = tp_connection_manager_get_protocol (priv->manager,
+     priv->protocol);
+  if (tp_protocol == NULL)
+    {
+      DEBUG ("Can't retrieve TpConnectionManagerProtocol for protocol '%s'",
+          priv->protocol);
+      return NULL;
+    }
+
+  return tp_protocol->params;
 }
 
 gboolean
@@ -734,6 +751,8 @@ empathy_account_settings_get_uint32 (EmpathyAccountSettings *settings,
   guint32 ret;
 
   v = empathy_account_settings_get (settings, param);
+  if (v == NULL)
+    return 0;
 
   switch G_VALUE_TYPE (v)
     {
