@@ -29,6 +29,7 @@
 #include <telepathy-glib/connection.h>
 #include <telepathy-glib/util.h>
 #include <telepathy-glib/dbus.h>
+#include <telepathy-glib/interfaces.h>
 
 #include "empathy-tp-contact-list.h"
 #include "empathy-tp-contact-factory.h"
@@ -973,10 +974,13 @@ tp_contact_list_add (EmpathyContactList *list,
 		tp_cli_channel_interface_group_call_add_members (priv->subscribe,
 			-1, &handles, message, NULL, NULL, NULL, NULL);
 	}
-	if (priv->publish &&
-	    g_hash_table_lookup (priv->pendings, GUINT_TO_POINTER (handle))) {
-		tp_cli_channel_interface_group_call_add_members (priv->publish,
-			-1, &handles, message, NULL, NULL, NULL, NULL);
+	if (priv->publish) {
+		TpChannelGroupFlags flags = tp_channel_group_get_flags (priv->subscribe);
+		if (flags & TP_CHANNEL_GROUP_FLAG_CAN_ADD ||
+		    g_hash_table_lookup (priv->pendings, GUINT_TO_POINTER (handle))) {
+			tp_cli_channel_interface_group_call_add_members (priv->publish,
+				-1, &handles, message, NULL, NULL, NULL, NULL);
+		}
 	}
 }
 
@@ -1165,21 +1169,24 @@ tp_contact_list_get_flags (EmpathyContactList *list)
 {
 	EmpathyTpContactListPriv *priv;
 	EmpathyContactListFlags flags;
-	TpChannelGroupFlags group_flags;
 
 	g_return_val_if_fail (EMPATHY_IS_TP_CONTACT_LIST (list), FALSE);
 
 	priv = GET_PRIV (list);
 	flags = priv->flags;
 
-	group_flags = tp_channel_group_get_flags (priv->subscribe);
+	if (priv->subscribe != NULL) {
+		TpChannelGroupFlags group_flags;
 
-	if (group_flags & TP_CHANNEL_GROUP_FLAG_CAN_ADD) {
-		flags |= EMPATHY_CONTACT_LIST_CAN_ADD;
-	}
+		group_flags = tp_channel_group_get_flags (priv->subscribe);
 
-	if (group_flags & TP_CHANNEL_GROUP_FLAG_CAN_REMOVE) {
-		flags |= EMPATHY_CONTACT_LIST_CAN_REMOVE;
+		if (group_flags & TP_CHANNEL_GROUP_FLAG_CAN_ADD) {
+			flags |= EMPATHY_CONTACT_LIST_CAN_ADD;
+		}
+
+		if (group_flags & TP_CHANNEL_GROUP_FLAG_CAN_REMOVE) {
+			flags |= EMPATHY_CONTACT_LIST_CAN_REMOVE;
+		}
 	}
 
 	return flags;
