@@ -59,6 +59,11 @@
 #define DEBUG_FLAG EMPATHY_DEBUG_CHAT
 #include <libempathy/empathy-debug.h>
 
+typedef struct {
+	EmpathyChatWindow *window;
+	EmpathyChat *chat;
+} NotificationData;
+
 #define GET_PRIV(obj) EMPATHY_GET_PRIV (obj, EmpathyChatWindow)
 typedef struct {
 	EmpathyChat *current_chat;
@@ -72,6 +77,7 @@ typedef struct {
 	GtkWidget   *dialog;
 	GtkWidget   *notebook;
 	NotifyNotification *notification;
+	NotificationData *notification_data;
 
 	/* Menu items. */
 	GtkUIManager *ui_manager;
@@ -910,10 +916,12 @@ chat_window_set_urgency_hint (EmpathyChatWindow *window,
 	gtk_window_set_urgency_hint (GTK_WINDOW (priv->dialog), urgent);
 }
 
-typedef struct {
-	EmpathyChatWindow *window;
-	EmpathyChat *chat;
-} NotificationData;
+static void
+free_notification_data (NotificationData *data)
+{
+	g_object_unref (data->chat);
+	g_slice_free (NotificationData, data);
+}
 
 static void
 chat_window_notification_closed_cb (NotifyNotification *notify,
@@ -931,8 +939,8 @@ chat_window_notification_closed_cb (NotifyNotification *notify,
 
 	g_object_unref (notify);
 	priv->notification = NULL;
-	g_object_unref (cb_data->chat);
-	g_slice_free (NotificationData, cb_data);
+	free_notification_data (cb_data);
+	priv->notification_data = NULL;
 }
 
 static void
@@ -972,6 +980,7 @@ chat_window_show_or_update_notification (EmpathyChatWindow *window,
 		cb_data->chat = g_object_ref (chat);
 		cb_data->window = window;
 
+		priv->notification_data = cb_data;
 		priv->notification = notify_notification_new (header, escaped, NULL, NULL);
 		notify_notification_set_timeout (priv->notification, NOTIFY_EXPIRES_DEFAULT);
 
@@ -1250,9 +1259,9 @@ chat_window_drag_data_received (GtkWidget        *widget,
 				EmpathyChatWindow *window)
 {
 	if (info == DND_DRAG_TYPE_CONTACT_ID) {
-		EmpathyChat           *chat;
+		EmpathyChat           *chat = NULL;
 		EmpathyChatWindow     *old_window;
-		EmpathyAccount        *account;
+		EmpathyAccount        *account = NULL;
 		EmpathyAccountManager *account_manager;
 		const gchar           *id;
 		gchar                **strv;
@@ -1264,11 +1273,21 @@ chat_window_drag_data_received (GtkWidget        *widget,
 
 		DEBUG ("DND contact from roster with id:'%s'", id);
 
-		strv = g_strsplit (id, "/", 2);
-		account_id = strv[0];
-		contact_id = strv[1];
-		account = empathy_account_manager_get_account (account_manager, account_id);
-		chat = empathy_chat_window_find_chat (account, contact_id);
+		strv = g_strsplit (id, ":", 2);
+		if (g_strv_length (strv) == 2) {
+			account_id = strv[0];
+			contact_id = strv[1];
+			account =
+				empathy_account_manager_get_account (account_manager, account_id);
+			if (account != NULL)
+				chat = empathy_chat_window_find_chat (account, contact_id);
+		}
+
+		if (account == NULL) {
+			g_strfreev (strv);
+			gtk_drag_finish (context, FALSE, FALSE, time);
+			return;
+		}
 
 		if (!chat) {
 			TpConnection *connection;
@@ -1365,6 +1384,11 @@ chat_window_finalize (GObject *object)
 		notify_notification_close (priv->notification, NULL);
 		g_object_unref (priv->notification);
 		priv->notification = NULL;
+		if (priv->notification_data != NULL)
+			{
+				free_notification_data (priv->notification_data);
+				priv->notification_data = NULL;
+			}
 	}
 
 	chat_windows = g_list_remove (chat_windows, window);
