@@ -81,6 +81,9 @@
 
 #define COMMAND_ACCOUNTS_DIALOG 1
 
+static gboolean account_dialog_only = FALSE;
+static gboolean start_hidden = FALSE;
+
 static void
 dispatch_cb (EmpathyDispatcher *dispatcher,
     EmpathyDispatchOperation *operation,
@@ -322,18 +325,37 @@ create_salut_account_if_needed (EmpathyConnectionManagers *managers)
   g_object_unref (book);
 }
 
+static gboolean
+has_non_salut_accounts (EmpathyAccountManager *manager)
+{
+  gboolean ret = FALSE;
+  GList *accounts, *l;
+
+  accounts = empathy_account_manager_dup_accounts (manager);
+
+  for (l = accounts ; l != NULL; l = g_list_next (l))
+    {
+      EmpathyAccount *account = EMPATHY_ACCOUNT (l->data);
+
+      if (tp_strdiff (empathy_account_get_protocol (l->data), "local-xmpp"))
+        ret = TRUE;
+
+      g_object_unref (account);
+    }
+
+  g_list_free (accounts);
+
+  return ret;
+}
+
 static void
 maybe_show_account_assistant (void)
 {
   EmpathyAccountManager *manager;
   manager = empathy_account_manager_dup_singleton ();
 
-  if (empathy_account_manager_get_count (manager) == 0)
-    {
-      GtkWidget * assistant = empathy_account_assistant_new (
-        GTK_WINDOW (empathy_main_window_get ()));
-      gtk_window_present (GTK_WINDOW (assistant));
-    }
+  if (!has_non_salut_accounts (manager))
+    empathy_account_assistant_show (GTK_WINDOW (empathy_main_window_get ()));
 }
 
 static gboolean
@@ -341,7 +363,7 @@ check_connection_managers_ready (EmpathyConnectionManagers *managers)
 {
   if (empathy_connection_managers_is_ready (managers))
     {
-      if (!empathy_import_mc4_accounts (managers))
+      if (!empathy_import_mc4_accounts (managers) && !start_hidden)
         maybe_show_account_assistant ();
 
       create_salut_account_if_needed (managers);
@@ -428,6 +450,60 @@ migrate_config_to_xdg_dir (void)
   g_free (old_dir);
 }
 
+static void
+do_show_accounts_ui (GtkWindow *window,
+    EmpathyAccountManager *manager)
+{
+
+  GtkWidget *ui;
+
+  if (has_non_salut_accounts (manager))
+    ui = empathy_accounts_dialog_show (window, NULL);
+  else
+    ui = empathy_account_assistant_show (window);
+
+  if (account_dialog_only)
+    g_signal_connect (ui, "destroy",
+      G_CALLBACK (gtk_main_quit), NULL);
+}
+
+static void
+account_manager_ready_for_accounts_cb (EmpathyAccountManager *manager,
+    GParamSpec *spec,
+    gpointer user_data)
+{
+  if (!empathy_account_manager_is_ready (manager))
+    return;
+
+  do_show_accounts_ui (user_data, manager);
+}
+
+static void
+show_accounts_ui (GtkWindow *window,
+    gboolean force)
+{
+  EmpathyAccountManager *manager;
+
+  manager = empathy_account_manager_dup_singleton ();
+  if (empathy_account_manager_is_ready (manager))
+    {
+      if (force)
+        do_show_accounts_ui (window, manager);
+      else
+        maybe_show_account_assistant ();
+    }
+  else if (force)
+    {
+      /* Only if we we're forced to show the widget connect to ready, otherwise
+       * the initial readyness will cause the accounts ui to be shown when
+       * needed */
+      g_signal_connect (manager, "notify::ready",
+        G_CALLBACK (account_manager_ready_for_accounts_cb), window);
+    }
+
+  g_object_unref (manager);
+}
+
 static UniqueResponse
 unique_app_message_cb (UniqueApp *unique_app,
     gint command,
@@ -435,17 +511,24 @@ unique_app_message_cb (UniqueApp *unique_app,
     guint timestamp,
     gpointer user_data)
 {
-  GtkWidget *window = user_data;
+  GtkWindow *window = user_data;
 
   DEBUG ("Other instance launched, presenting the main window. "
       "Command=%d, timestamp %u", command, timestamp);
 
   if (command == COMMAND_ACCOUNTS_DIALOG)
     {
-      empathy_accounts_dialog_show (GTK_WINDOW (window), NULL);
+      show_accounts_ui (window, TRUE);
     }
   else
     {
+      /* We're requested to show stuff again, disable the start hidden global
+       * in case the accounts wizard wants to pop up.
+       */
+      start_hidden = FALSE;
+
+      show_accounts_ui (window, FALSE);
+
       gtk_window_set_screen (GTK_WINDOW (window),
           unique_message_data_get_screen (data));
       gtk_window_set_startup_id (GTK_WINDOW (window),
@@ -552,7 +635,7 @@ account_manager_ready_cb (EmpathyAccountManager *manager,
             G_CALLBACK (connection_managers_ready_cb), NULL);
         }
     }
-  else
+  else if (!start_hidden)
     {
       maybe_show_account_assistant ();
     }
@@ -728,8 +811,6 @@ main (int argc, char *argv[])
   EmpathyConnectivity *connectivity;
   gboolean autoconnect = TRUE;
   gboolean no_connect = FALSE;
-  gboolean hide_contact_list = FALSE;
-  gboolean accounts_dialog = FALSE;
   GError *error = NULL;
   TpDBusDaemon *dbus_daemon;
   UniqueApp *unique_app;
@@ -742,11 +823,11 @@ main (int argc, char *argv[])
         N_("Don't connect on startup"),
         NULL },
       { "hide-contact-list", 'h',
-        0, G_OPTION_ARG_NONE, &hide_contact_list,
+        0, G_OPTION_ARG_NONE, &start_hidden,
         N_("Don't show the contact list on startup"),
         NULL },
       { "accounts", 'a',
-        0, G_OPTION_ARG_NONE, &accounts_dialog,
+        0, G_OPTION_ARG_NONE, &account_dialog_only,
         N_("Show the accounts dialog"),
         NULL },
       { "version", 'v',
@@ -794,7 +875,7 @@ main (int argc, char *argv[])
 
   if (unique_app_is_running (unique_app))
     {
-      unique_app_send_message (unique_app, accounts_dialog ?
+      unique_app_send_message (unique_app, account_dialog_only ?
           COMMAND_ACCOUNTS_DIALOG : UNIQUE_ACTIVATE, NULL);
 
       g_object_unref (unique_app);
@@ -821,15 +902,14 @@ main (int argc, char *argv[])
       g_clear_error (&error);
     }
 
-  if (accounts_dialog)
+  if (account_dialog_only)
     {
-      GtkWidget *dialog;
-
-      dialog = empathy_accounts_dialog_show (NULL, NULL);
-      g_signal_connect (dialog, "destroy",
-                        G_CALLBACK (gtk_main_quit), NULL);
+      account_manager = empathy_account_manager_dup_singleton ();
+      show_accounts_ui (NULL, TRUE);
 
       gtk_main ();
+
+      g_object_unref (account_manager);
       return 0;
     }
 
@@ -868,7 +948,7 @@ main (int argc, char *argv[])
 
   /* Setting up UI */
   window = empathy_main_window_show ();
-  icon = empathy_status_icon_new (GTK_WINDOW (window), hide_contact_list);
+  icon = empathy_status_icon_new (GTK_WINDOW (window), start_hidden);
 
   g_signal_connect (unique_app, "message-received",
       G_CALLBACK (unique_app_message_cb), window);
