@@ -7,6 +7,7 @@
 
 #include "check-helpers.h"
 #include "check-libempathy.h"
+#include <libempathy/empathy-utils.h>
 
 #include "config.h"
 
@@ -34,6 +35,7 @@ main (void)
 
     check_helpers_init ();
     g_type_init ();
+    empathy_init ();
 
     s = make_libempathy_suite ();
     sr = srunner_create (s);
